unit CaptionPanel;

{$IFDEF FPC}
  {$mode objfpc}{$H+}
{$ENDIF}

interface

uses
  SysUtils, Classes, Controls, StdCtrls, ExtCtrls, Buttons, Graphics, ComCtrls,
  Dialogs
  {$IFDEF FPC}
  ,LResources
  {$ENDIF};

resourcestring
  hintHelp     = 'Hilfe ffnen';
  hintIconize  = 'Als Icon darstellen';
  hintMinimize = 'Verkleinern';
  hintMaximize = 'Originalgre herstellen';
  hintFormWiz  = 'Als Formular darstellen';
  hintClose    = 'Formular schlieen';

type

  TCaptionBarButtonSet = (btn_help, btn_iconize, btn_resize, btn_formwiz,
                          btn_close);
  TCaptionBarButtons = Set of TCaptionBarButtonSet;
  TCaptionBarButton = btn_help..btn_close;

  TCaptionPanel = class(TCustomPanel)
  private
    { Private-Deklarationen }
    FCtrlButtons: TCaptionBarButtons;
    FButtonPanel: TCustomPanel;
    FBitmapPrefix: string;
    FFormIcon: TImage;
    FOwnerCaption: TPanel;
    FButtonArr: array[btn_help..btn_close] of TSpeedButton;
    FMinimized: boolean;
    FOnHelp: TNotifyEvent;
    FOnIconize: TNotifyEvent;
    FOnOwnerResize: TNotifyEvent;
    FOnFormwiz: TNotifyEvent;
    FOnClose: TNotifyEvent;

    procedure SetBitmapPrefix(h: integer);
    function  GetOwnerCaption: string;
    procedure SetOwnerCaption(Value: string);
    function  GetFormIcon: TPicture;
    procedure SetFormIcon(Value: TPicture);
    function  GetCaptionFont: TFont;
    procedure SetCaptionFont(Value: TFont);
    function  GetCaptionColor: TColor;
    procedure SetCaptionColor(Value: TColor);
    procedure SetCtrlButtons(Value: TCaptionBarButtons);
    procedure DoResize(Sender: TObject);

    function  CreateButton(btnFlag: TCaptionBarButton): TSpeedButton;
    procedure ResizeButtonPanel;
    procedure DoOnHelp(Sender: TObject);
    procedure DoOnIconize(Sender: TObject);
    procedure DoOnOwnerResize(Sender: TObject);
    procedure DoOnFormwiz(Sender: TObject);
    procedure DoOnClose(Sender: TObject);

    procedure SetButtonPic(Btn: TSpeedButton; btnFlag: TCaptionBarButton);
    procedure SetEventProc(Btn: TSpeedButton; btnFlag: TCaptionBarButton);
    function  LoadGlyph(const GlyphName: string): TBitmap;

  protected
    { Protected-Deklarationen }

  public
    { Public-Deklarationen }
    constructor Create(AOwner: TComponent); override;
    destructor  Destroy;
  published
    { Published-Deklarationen }
    property CtrlButtons: TCaptionBarButtons
              read FCtrlButtons write SetCtrlButtons;
    property OwnerCaption: string read GetOwnerCaption write SetOwnerCaption;
    property FormIcon: TPicture read GetFormIcon write SetFormIcon;
    property Minimized: boolean read FMinimized write FMinimized;
    property CaptionFont: TFont read GetCaptionFont write SetCaptionFont;
    property CaptionColor: TColor read GetCaptionColor write SetCaptionColor;

    { Eventhandling }
    property OnHelp: TNotifyEvent read FOnHelp write FOnHelp;
    property OnIconize: TNotifyEvent read FOnIconize write FOnIconize;
    property OnOwnerResize: TNotifyEvent
      read FOnOwnerResize write FOnOwnerResize;
    property OnFormwiz: TNotifyEvent read FOnFormwiz write FOnFormwiz;
    property OnClose: TNotifyEvent read FOnClose write FOnClose;

  end; // of TCaptionPanel

procedure Register();

implementation

{$IFNDEF FPC}
  {$R *.res}

uses
  NGImages;
{$ELSE}
uses
  lazpnm, lazjpg, laztga, lazpng, lazxpm, lazbmp;
{$ENDIF}

procedure Register();
begin
  RegisterComponents('Control-Bars', [TCaptionPanel]);
end; // of Register

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   Create
  Author:    root
  Date:      02-Jan-2007
  Arguments: AOwner: TComponent
-----------------------------------------------------------------------------}
constructor TCaptionPanel.Create(AOwner: TComponent);
const
  cProcName = 'CaptionPanel.TCaptionPanel.Create';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'AOwner: TComponent'
  end; // of function SetErrorParams: string

var
  btnFlag: TCaptionBarButton;

begin
  { procedure body }
  inherited Create(AOwner);
  Self.BevelInner:= bvLowered;
  Self.BevelOuter:= bvRaised;
  if (Self.Height < 21) or (Self.Height > 31) then begin
    if (Self.Height < 21) then Self.Height:= 26;
    if (Self.Height > 31) then Self.Height:= 31;
  end; // of if (Self.Height < 21) or (Self.Height > 31) then begin
  Self.Caption:= '';
  Self.Align:= alTop;
  Self.Parent:= TWinControl(AOwner);
  Self.ShowHint:= true;
  FFormIcon:= TImage.Create(Self);
  FFormIcon.Parent:= Self;
  FFormIcon.Width := Self.ClientHeight - 2 * Self.BevelWidth;
  FFormIcon.Align:= alLeft;
  FFormIcon.Stretch:= true;
  FButtonPanel:= TCustomPanel.Create(Self);
  FButtonPanel.Width:= 0;
  FButtonPanel.Align:= alRight;
  FButtonPanel.Parent:= Self;
  FButtonPanel.ShowHint:= true;
  FOwnerCaption:= TPanel.Create(Self);
  FOwnerCaption.BevelInner:= bvNone;
  FOwnerCaption.BevelOuter:= bvNone;
  FOwnerCaption.BorderWidth:= 2;
  FOwnerCaption.Align:= alClient;
  FOwnerCaption.Alignment:= taLeftJustify;
  FOwnerCaption.Color:= clNavy;
  FOwnerCaption.Font.Style:= [fsBold];
  FOwnerCaption.Font.Color:= clWhite;
  OwnerCaption:= TComponent(AOwner).Name;
  FOwnerCaption.Parent:= Self;
  FMinimized:= false;
  for btnFlag:= btn_help to btn_close
    do FButtonArr[btnFlag]:= Self.CreateButton(btnFlag);
  if (CtrlButtons = [])
    then CtrlButtons:= [btn_close];
  FFormIcon.Picture.Bitmap:= Self.LoadGlyph('22X22RUN');
  {$IFNDEF FPC}
  Self.OnResize:= DoResize;
  {$ELSE}
  Self.OnResize:= @DoResize;
  {$ENDIF}
end; // of TCaptionPanel.Create

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   Destroy
  Author:    root
  Date:      06-Jan-2007
  Arguments: None
-----------------------------------------------------------------------------}
destructor TCaptionPanel.Destroy;
const
  cProcName = 'CaptionPanel.TCaptionPanel.Destroy';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  inherited;
end; // of TCaptionPanel.Destroy

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetBitmapPrefix
  Author:    root
  Date:      15-Jan-2007
  Arguments: h: integer
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetBitmapPrefix(h: integer);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetBitmapPrefix';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'h: integer'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if h <= 24
    then FBitmapPrefix:= '16X16'
    else FBitmapPrefix:= '22X22';
end; // of TCaptionPanel.SetBitmapPrefix

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetOwnerCaption
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    string
-----------------------------------------------------------------------------}
function TCaptionPanel.GetOwnerCaption: string;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetOwnerCaption';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'string';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FOwnerCaption.Caption;
end; // of TCaptionPanel.GetOwnerCaption

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetOwnerCaption
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: string
  Subject: set the Caption for this Panel interactive
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetOwnerCaption(Value: string);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetOwnerCaption';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: string'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> FOwnerCaption.Caption) then begin
    FOwnerCaption.Caption:= ' ' + Value;
  end;
end; // of TCaptionPanel.SetOwnerCaption

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetFormIcon
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    TPicture
-----------------------------------------------------------------------------}
function TCaptionPanel.GetFormIcon: TPicture;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetFormIcon';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'TPicture';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FFormIcon.Picture;
end; // of TCaptionPanel.GetFormIcon

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetFormIcon
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: TPicture
  Subject: set the Formicon for this Panel interactive
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetFormIcon(Value: TPicture);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetFormIcon';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TPicture'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> nil) and (Value <> FFormIcon.Picture) then begin
    FFormIcon.Picture:= Value;
  end;
end; // of TCaptionPanel.SetFormIcon

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetCaptionFont
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    TFont
-----------------------------------------------------------------------------}
function TCaptionPanel.GetCaptionFont: TFont;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetCaptionFont';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'TFont';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FOwnerCaption.Font;
end; // of TCaptionPanel.GetCaptionFont

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetCaptionFont
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: TFont
  Subject: set the Captionfont for this Panel interactive
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetCaptionFont(Value: TFont);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetCaptionFont';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TFont'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> FOwnerCaption.Font) then begin
    FOwnerCaption.Font:= Value;
  end;
end; // of TCaptionPanel.SetCaptionFont

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    GetCaptionColor
  Author:    root
  Date:      02-Jan-2007
  Arguments: None
  Result:    TColor
-----------------------------------------------------------------------------}
function TCaptionPanel.GetCaptionColor: TColor;
const
  cProcName = 'CaptionPanel.TCaptionPanel.GetCaptionColor';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
    // 'TColor';
  end; // of function SetErrorParams: string

begin
  { function body }
  Result:= FOwnerCaption.Color;
end; // of TCaptionPanel.GetCaptionColor

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetCaptionColor
  Author:    root
  Date:      02-Jan-2007
  Arguments: Value: TColor
  Subject: set the Caption Backgroundcolor
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetCaptionColor(Value: TColor);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetCaptionColor';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TColor'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if (Value <> FOwnerCaption.Color) then begin
    FOwnerCaption.Color:= Value;
  end;
end; // of TCaptionPanel.SetCaptionColor

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetCtrlButtons
  Author:    root
  Date:      11-Jan-2007
  Arguments: Value: TCaptionBarButtons

  Subject: set or unset ControlButtons
    set FButtonPanel invisible if no Buttons are active
    otherwise set FButtonPanel visible and show active
    Buttons
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetCtrlButtons(Value: TCaptionBarButtons);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetCtrlButtons';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Value: TCaptionBarButtons'
  end; // of function SetErrorParams: string

var
  btnFlag: TCaptionBarButton;
  count  : integer;
begin
  { procedure body }
  FCtrlButtons:= Value;
  count:= 0;
  Invalidate;
  FButtonPanel.Invalidate;
  if (FCtrlButtons <> []) then begin
    // some or all Buttons active
    FButtonPanel.Visible:= true;
    Self.ResizeButtonPanel;
  end
  else begin
    // no Buttons active
    FButtonPanel.Width  := 0;
    FButtonPanel.Visible:= false;
  end; // of else begin
  Repaint;
end; // of TCaptionPanel.SetCtrlButtons

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   DoResize
  Author:    root
  Date:      15-Jan-2007
  Arguments: Sender: TObject
-----------------------------------------------------------------------------}
procedure TCaptionPanel.DoResize(Sender: TObject);
const
  cProcName = 'CaptionPanel.TCaptionPanel.DoResize';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Sender: TObject'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  Invalidate;
  if (Self.Height < 21) or (Self.Height > 31) then begin
    if (Self.Height < 21) then Self.Height:= 26;
    if (Self.Height > 31) then Self.Height:= 31;
  end; // of if (Self.Height < 21) or (Self.Height > 31) then begin
  if (FFormIcon <> nil)
    then FFormIcon.Width:= Self.ClientHeight - 2 * Self.BevelWidth;
  if (FButtonPanel <> nil) then ResizeButtonPanel;
  Repaint;
end; // of TCaptionPanel.DoResize

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetButtonPic
  Author:    root
  Date:      15-Jan-2007
  Arguments: Btn: TSpeedButton; btnFlag: TCaptionBarButton
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetButtonPic(Btn: TSpeedButton;
                                     btnFlag: TCaptionBarButton);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetButtonPic';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Btn: TSpeedButton; btnFlag: TCaptionBarButton'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  Self.SetBitmapPrefix(Btn.Height);
  case btnFlag of
    btn_help   : Btn.Glyph:= Self.LoadGlyph(FBitmapPrefix + 'BTN_HELP');
    btn_iconize: Btn.Glyph:= Self.LoadGlyph(FBitmapPrefix + 'BTN_ICONIZE');
    btn_resize : if Self.FMinimized
      then Btn.Glyph:= Self.LoadGlyph(FBitmapPrefix + 'BTN_MAXIMIZE')
      else Btn.Glyph:= Self.LoadGlyph(FBitmapPrefix + 'BTN_MINIMIZE');
    btn_formwiz: Btn.Glyph:= Self.LoadGlyph(FBitmapPrefix + 'BTN_FORMWIZ');
    btn_close  : Btn.Glyph:= Self.LoadGlyph(FBitmapPrefix + 'BTN_CLOSE');
  end; // of case btnFlag of
end; // of TCaptionPanel.SetButtonPic

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   SetEventProc
  Author:    root
  Date:      15-Jan-2007
  Arguments: Btn: TSpeedButton; btnFlag: TCaptionBarButton
-----------------------------------------------------------------------------}
procedure TCaptionPanel.SetEventProc(Btn: TSpeedButton;
                                     btnFlag: TCaptionBarButton);
const
  cProcName = 'CaptionPanel.TCaptionPanel.SetEventProc';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Btn: TSpeedButton; btnFlag: TCaptionBarButton'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  case btnFlag of
    btn_help   : {$IFNDEF FPC} Btn.OnClick:= Self.DoOnHelp;
                 {$ELSE}       Btn.OnClick:= @DoOnHelp; {$ENDIF}
    btn_iconize: {$IFNDEF FPC} Btn.OnClick:= Self.DoOnIconize;
                 {$ELSE}       Btn.OnClick:= @DoOnIconize; {$ENDIF}
    btn_resize : {$IFNDEF FPC} Btn.OnClick:= Self.DoOnOwnerResize;
                 {$ELSE}       Btn.OnClick:= @DoOnOwnerResize; {$ENDIF}
    btn_formwiz: {$IFNDEF FPC} Btn.OnClick:= Self.DoOnFormwiz;
                 {$ELSE}       Btn.OnClick:= @DoOnFormwiz; {$ENDIF}
    btn_close  : {$IFNDEF FPC} Btn.OnClick:= Self.DoOnClose;
                 {$ELSE}       Btn.OnClick:= @DoOnClose; {$ENDIF}
  end; // of case btnFlag of
end; // of TCaptionPanel.SetEventProc

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    LoadGlyph
  Author:    root
  Date:      02-Jan-2007
  Arguments: const GlyphName: string
  Result:    TBitmap
  Subject: loads the Bitmaps for any Control who need it
-----------------------------------------------------------------------------}
function TCaptionPanel.LoadGlyph(const GlyphName: string): TBitmap;
const
  cProcName = 'CaptionPanel.TCaptionPanel.LoadGlyph';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'const GlyphName: string'
    // 'TBitmap';
  end; // of function SetErrorParams: string

var
  Image: TPNGImage;

begin
  { function body }

  try
    Image:= TPNGImage.Create;
    Result:= TBitmap.Create;
    {$IFNDEF FPC}
    Image.LoadFromResource(HInstance, GlyphName, 'PNG');
    Result:= Image.CopyBitmap;
    {$ELSE}
    Image.LoadFromLazarusResource(LowerCase(GlyphName));
    Result.Assign(Image);
    {$ENDIF}
  finally
    Image.Free;
  end;
end; // of TCaptionPanel.LoadGlyph

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Method:    CreateButton
  Author:    root
  Date:      06-Jan-2007
  Arguments: btnFlag: TCaptionBarButton
  Result:    TSpeedButton
  Subject: creates the ControlButtons for this Panel an initalizes there
           Hints and Bitmaps
-----------------------------------------------------------------------------}
function TCaptionPanel.CreateButton(btnFlag: TCaptionBarButton): TSpeedButton;
const
  cProcName = 'CaptionPanel.TCaptionPanel.CreateButton';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'btnName : string; btnIndex: integer'
    // 'TSpeedButton';
  end; // of function SetErrorParams: string

var
  btn: TSpeedButton;
begin
  { function body }
  btn:= TSpeedButton.Create(FButtonPanel);
  btn.Width:= btn.Height + 1;
  btn.Parent:= FButtonPanel;
  btn.Visible := true;
  btn.Spacing := 0;
  btn.Cursor  := crHandPoint;
  btn.Layout  := blGlyphLeft;
  btn.ShowHint:= true;
  Self.SetEventProc(btn, btnFlag);
  Self.SetButtonPic(btn, btnFlag);
  case btnFlag of
    btn_help: begin
      btn.Name   := 'btnHelp';
      btn.Hint   := hintHelp;
    end; // of btn_help
    btn_iconize: begin
      btn.Name   := 'btnIconize';
      btn.Hint   := hintIconize;
    end; // of btn_iconize
    btn_resize: begin
      btn.Name   := 'btnResize';
      if Self.FMinimized
        then btn.Hint:= hintMaximize
        else btn.Hint:= hintMinimize;
    end; // of btn_resize
    btn_formwiz: begin
      btn.Name   := 'btnFormwiz';
      btn.Hint   := hintFormwiz;
    end; // of btn_formwiz
    btn_close: begin
      btn.Name   := 'btnClose';
      btn.Hint   := hintClose;
    end; // of btn_close
  end; // of case btnFlag of
  Result:= btn;
end; // of TCaptionPanel.CreateButton

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   ResizeButtonPanel
  Author:    root
  Date:      10-Jan-2007
  Arguments: None
  Subject: resizes FButtonPanel and sets the Positions for all active
           Buttons on it
-----------------------------------------------------------------------------}
procedure TCaptionPanel.ResizeButtonPanel;
const
  cProcName = 'CaptionPanel.TCaptionPanel.ResizeButtonPanel';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'None'
  end; // of function SetErrorParams: string

var
  count,
  xl,
  bw     : integer;
  btnFlag: TCaptionBarButton;
begin
  { procedure body }
  bw:= FButtonPanel.ClientHeight + 1;
  count:= 0;
  for btnFlag:= btn_close downto btn_help do begin
    TSpeedButton(FButtonArr[btnFlag]).Width:= bw;
    TSpeedButton(FButtonArr[btnFlag]).Height:= FButtonPanel.ClientHeight;
    Self.SetButtonPic(FButtonArr[btnFlag], btnFlag);
    if (btnFlag in  FCtrlButtons) then begin
      TSpeedButton(FButtonArr[btnFlag]).Visible:= true;
      inc(count);
    end
    else TSpeedButton(FButtonArr[btnFlag]).Visible:= false;
  end; // of for btnFlag:= btn_close downto btn_help do begin
  FButtonPanel.Width:= count * bw;
  xl:= FButtonPanel.Width - bw;
  for btnFlag:= btn_close downto btn_help do begin
    if TSpeedButton(FButtonArr[btnFlag]).Visible then begin
      TSpeedButton(FButtonArr[btnFlag]).Left:= xl;
      xl:= xl - bw;
    end; // of if TSpeedButton(FButtonArr[btnFlag]).Visible then begin
  end; // of for btnFlag:= btn_close downto btn_help do begin
end; // of TCaptionPanel.ResizeButtonPanel

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   DoOnHelp
  Author:    root
  Date:      07-Jan-2007
  Arguments: Sender: TObject
-----------------------------------------------------------------------------}
procedure TCaptionPanel.DoOnHelp(Sender: TObject);
const
  cProcName = 'CaptionPanel.TCaptionPanel.DoOnHelp';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Sender: TObject'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if Assigned(FOnHelp) then OnHelp(Self);
end; // of TCaptionPanel.DoOnHelp

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   DoOnIconize
  Author:    root
  Date:      07-Jan-2007
  Arguments: Sender: TObject
-----------------------------------------------------------------------------}
procedure TCaptionPanel.DoOnIconize(Sender: TObject);
const
  cProcName = 'CaptionPanel.TCaptionPanel.DoOnIconize';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Sender: TObject'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if Assigned(FOnIconize) then OnIconize(Self);
end; // of TCaptionPanel.DoOnIconize

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   DoOnOwnerResize
  Author:    root
  Date:      07-Jan-2007
  Arguments: Sender: TObject
-----------------------------------------------------------------------------}
procedure TCaptionPanel.DoOnOwnerResize(Sender: TObject);
const
  cProcName = 'CaptionPanel.TCaptionPanel.DoOnOwnerResize';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Sender: TObject'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if Assigned(FOnOwnerResize) then OnOwnerResize(Self);
  if FMinimized then begin
    TSpeedButton(Sender).Hint := hintMaximize;
    TSpeedButton(Sender).Glyph:= LoadGlyph(FBitmapPrefix + 'BTN_MAXIMIZE');
  end
  else begin
    TSpeedButton(Sender).Hint := hintMinimize;
    TSpeedButton(Sender).Glyph:= LoadGlyph(FBitmapPrefix + 'BTN_MINIMIZE');
  end;
end; // of TCaptionPanel.DoOnOwnerResize

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   DoOnFormwiz
  Author:    root
  Date:      11-Jan-2007
  Arguments: Sender: TObject
-----------------------------------------------------------------------------}
procedure TCaptionPanel.DoOnFormwiz(Sender: TObject);
const
  cProcName = 'CaptionPanel.TCaptionPanel.DoOnFormwiz';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Sender: TObject'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if Assigned(FOnFormwiz) then OnFormwiz(Self);
end; // of TCaptionPanel.DoOnFormwiz

{-----------------------------------------------------------------------------
  Class:     TCaptionPanel
  Methode:   DoOnClose
  Author:    root
  Date:      07-Jan-2007
  Arguments: Sender: TObject
-----------------------------------------------------------------------------}
procedure TCaptionPanel.DoOnClose(Sender: TObject);
const
  cProcName = 'CaptionPanel.TCaptionPanel.DoOnClose';

  function SetErrorParams: string;
  begin
    Result:= '';
    // 'Sender: TObject'
  end; // of function SetErrorParams: string

begin
  { procedure body }
  if Assigned(FOnClose) then OnClose(Self);
end; // of TCaptionPanel.DoOnClose

{-----------------------------------------------------------------------------
 Unit Name: CaptionPanel
 Author:    root
 Date:      02-Jan-2007
 Purpose:
 History:
-----------------------------------------------------------------------------}
{$IFDEF FPC}
initialization
  LazPNG.Register;
  LazXPM.Register;
  LazBMP.Register;
  LazPNM.Register;
  LazTGA.Register;
  LazJPG.Register;
  {$I captionpanel.lrs}

finalization
  LazPNG.UnRegister;
  LazXPM.UnRegister;
  LazBMP.UnRegister;
  LazPNM.UnRegister;
  LazTGA.UnRegister;
  LazJPG.UnRegister;
{$ENDIF}

end.
